#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.2.0.0
visibility:           public
id:                   hls-plugin-api-2.2.0.0-E3eJBydQK4RHsefKQ86fIZ
key:                  hls-plugin-api-2.2.0.0-E3eJBydQK4RHsefKQ86fIZ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  56c655b1140ad4826434b8bb093f50a4
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.2.0.0-E3eJBydQK4RHsefKQ86fIZ
depends:
    Diff-0.5-LA74YNXpKBoKP5r3VLShKB
    aeson-2.2.1.0-71Mjpfr68qlJhyWUyvWYLm base-4.18.2.1
    co-log-core-0.3.2.6-AkooIvf8mcK9LdjX1Jp4hv containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dependent-map-0.4.0.1-LQuemFuySee2Rnz6pc4J77
    dependent-sum-0.7.2.0-D4ybmLI0tGL7C4DTQTjclC
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO extra-1.7.16-AZZkJf8uXcBmNBZ3QBrWg
    filepath-1.4.300.1 ghc-9.6.6
    hashable-1.4.7.0-H6imxCsecEO4wNDTcxh8s7
    hls-graph-2.2.0.0-8bW4HYNgP63G9VX83em3XU
    hw-fingertree-0.1.2.1-B6HfRxEKl0ZA3r2cJUIDop
    lens-5.3.3-BIkEQ5Q1REJ2CNEw0KPAWg
    lens-aeson-1.2.3-FMsYgxUmwhSIH6lnYIIDjk
    lsp-2.2.0.0-DtQZ3bAd01YGO9tVe1dGv9
    megaparsec-9.7.0-1ahLvlg5ek35YEPIMRfXbz mtl-2.3.1
    opentelemetry-0.8.0-A2uxrRYbNyHIjcGZiHrQCS
    optparse-applicative-0.18.1.0-4BezxXoHIckIHconhtKlD7
    prettyprinter-1.7.1-Egfz8R6Hy2931hrqdwzdET
    regex-tdfa-1.3.2.5-2nQDC1BQ0cwDMHgeFOi4Qc
    row-types-1.0.1.2-AWCXeJUr5iIIVdJYPBJmKM stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-5vu44DFyj36GEy0XeHfEHW
    unordered-containers-0.2.20.1-KjVwmKBzsCnE6cNwSXaI5c

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

